<?php

class ControllerExtensionPaymentCkassa extends Controller {

    private $error = array();

    public function index() {

        $this->load->language('extension/payment/ckassa');
        $this->load->model('localisation/order_status');

        $this->document->setTitle($this->language->get('heading_title'));
        
        $this->load->model('setting/setting');
        
        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {

            $this->model_setting_setting->editSetting('payment_ckassa', $this->request->post);
            $this->session->data['success'] = $this->language->get('text_success');
            $this->response->redirect($this->url->link('marketplace/extension', '&type=payment&user_token=' . $this->session->data['user_token'], true));
        }

        $data['heading_title'] = $this->language->get('heading_title');
        $data['text_edit'] = $this->language->get('text_edit');

        $data['button_save'] = $this->language->get('button_save');
        $data['button_cancel'] = $this->language->get('button_cancel');

        $data['tab_general'] = $this->language->get('tab_general');

        $data = array_merge($data, $this->prepareConfiguration());

        $data['error'] = $this->error;
        if (isset($this->error['warning'])) {
            $data['error_warning'] = $this->error['warning'];
        } else {
            $data['error_warning'] = '';
        }

        if (isset($this->error['ckassa_url'])) {
            $data['ckassa_url_error'] = $this->error['ckassa_url'];
        } else {
            $data['ckassa_url_error'] = '';
        }

        if (isset($this->error['ckassa_secret'])) {
            $data['ckassa_secret_error'] = $this->error['ckassa_secret'];
        } else {
            $data['ckassa_secret_error'] = '';
        }

        if (isset($this->error['ckassa_shop_key'])) {
            $data['ckassa_shop_key_error'] = $this->error['ckassa_shop_key'];
        } else {
            $data['ckassa_shop_key_error'] = '';
        }

        // label and option titles
        $data['entry_ckassa_status'] = $this->language->get('entry_ckassa_status');
        $data['entry_ckassa_invunic'] = $this->language->get('entry_ckassa_invunic');
        $data['entry_ckassa_is_test'] = $this->language->get('entry_ckassa_is_test');
        $data['entry_ckassa_url'] = $this->language->get('entry_ckassa_url');
        $data['entry_ckassa_cb_url'] = $this->language->get('entry_ckassa_cb_url');
        $data['entry_ckassa_success_url'] = $this->language->get('entry_ckassa_success_url');
        $data['entry_ckassa_fail_url'] = $this->language->get('entry_ckassa_fail_url');
        $data['entry_ckassa_secret'] = $this->language->get('entry_ckassa_secret');
        $data['entry_ckassa_shop_key'] = $this->language->get('entry_ckassa_shop_key');
        $data['entry_ckassa_currency'] = $this->language->get('entry_ckassa_currency');
        $data['entry_ckassa_lang'] = $this->language->get('entry_ckassa_lang');
        $data['entry_ckassa_country'] = $this->language->get('entry_ckassa_country');
        $data['entry_ckassa_taxation'] = $this->language->get('entry_ckassa_taxation');
        $data['entry_ckassa_tax'] = $this->language->get('entry_ckassa_tax');
        $data['entry_ckassa_tax_delivery'] = $this->language->get('entry_ckassa_tax_delivery');
        $data['entry_ckassa_payment_method'] = $this->language->get('entry_ckassa_payment_method');
        $data['entry_ckassa_payment_object'] = $this->language->get('entry_ckassa_payment_object');
        $data['entry_ckassa_sort_order'] = $this->language->get('entry_ckassa_sort_order');


        $data['entry_ckassa_order_status_before_payment'] = $this->language->get('entry_ckassa_order_status_before_payment');
        $data['entry_ckassa_order_status_after_payment'] = $this->language->get('entry_ckassa_order_status_after_payment');

        $data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();

        $data['countries'] = ["RU", "KZ"];

        $data['taxation'] = [
            ['title' => $this->language->get('entry_ckassa_taxation_osn'), 'value' => 'osn'],
            ['title' => $this->language->get('entry_ckassa_taxation_usn_income'), 'value' => 'usn_income'],
            ['title' => $this->language->get('entry_ckassa_taxation_usn_income_outcome'), 'value' => 'usn_income_outcome'],
            ['title' => $this->language->get('entry_ckassa_taxation_envd'), 'value' => 'envd'],
            ['title' => $this->language->get('entry_ckassa_taxation_esn'), 'value' => 'esn'],
            ['title' => $this->language->get('entry_ckassa_taxation_patent'), 'value' => 'patent'],
        ];

        $data['tax'] = [
            ['title' => $this->language->get('entry_ckassa_tax_none'), 'value' => 'none'],
            ['title' => $this->language->get('entry_ckassa_tax_vat10'), 'value' => 'vat10'],
            ['title' => $this->language->get('entry_ckassa_tax_vat18'), 'value' => 'vat18'],
            ['title' => $this->language->get('entry_ckassa_tax_vat110'), 'value' => 'vat110'],
            ['title' => $this->language->get('entry_ckassa_tax_vat118'), 'value' => 'vat118'],
            ['title' => $this->language->get('entry_ckassa_tax_vat20'), 'value' => 'vat20'],
            ['title' => $this->language->get('entry_ckassa_tax_vat120'), 'value' => 'vat120'],
        ];

        $data['payment_method'] = [
            ['title' => $this->language->get('entry_ckassa_payment_method_full_prepayment'), 'value' => 'full_prepayment'],
            ['title' => $this->language->get('entry_ckassa_payment_method_prepayment'), 'value' => 'prepayment'],
            ['title' => $this->language->get('entry_ckassa_payment_method_advance'), 'value' => 'advance'],
            ['title' => $this->language->get('entry_ckassa_payment_method_full_payment'), 'value' => 'full_payment'],
            ['title' => $this->language->get('entry_ckassa_payment_method_partial_payment'), 'value' => 'partial_payment'],
            ['title' => $this->language->get('entry_ckassa_payment_method_credit'), 'value' => 'credit'],
            ['title' => $this->language->get('entry_ckassa_payment_method_credit_payment'), 'value' => 'credit_payment'],
        ];

        $data['payment_object'] = [
            ['title' => $this->language->get('entry_ckassa_payment_object_commodity'), 'value' => 'commodity'],
            ['title' => $this->language->get('entry_ckassa_payment_object_excise'), 'value' => 'excise'],
            ['title' => $this->language->get('entry_ckassa_payment_object_job'), 'value' => 'job'],
            ['title' => $this->language->get('entry_ckassa_payment_object_service'), 'value' => 'service'],
            ['title' => $this->language->get('entry_ckassa_payment_object_gambling_bet'), 'value' => 'gambling_bet'],
            ['title' => $this->language->get('entry_ckassa_payment_object_gambling_prize'), 'value' => 'gambling_prize'],
            ['title' => $this->language->get('entry_ckassa_payment_object_lottery'), 'value' => 'lottery'],
            ['title' => $this->language->get('entry_ckassa_payment_object_lottery_prize'), 'value' => 'lottery_prize'],
            ['title' => $this->language->get('entry_ckassa_payment_object_intellectual_activity'), 'value' => 'intellectual_activity'],
            ['title' => $this->language->get('entry_ckassa_payment_object_payment'), 'value' => 'payment'],
            ['title' => $this->language->get('entry_ckassa_payment_object_agent_commission'), 'value' => 'agent_commission'],
            ['title' => $this->language->get('entry_ckassa_payment_object_composite'), 'value' => 'composite'],
            ['title' => $this->language->get('entry_ckassa_payment_object_another'), 'value' => 'another'],
        ];

        $data['invunic'] = [
            ['title' => $this->language->get('entry_ckassa_invunic_simple'), 'value' => 'SIMPLE'],
            ['title' => $this->language->get('entry_ckassa_invunic_created'), 'value' => 'CREATED'],
            ['title' => $this->language->get('entry_ckassa_invunic_none'), 'value' => 'NONE']
        ];

        $data['breadcrumbs'] = array();

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/home', 'user_token=' . $this->session->data['user_token'], 'SSL'),
            'separator' => false
        );

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_payment'),
            'href' => $this->url->link('extension/payment', 'user_token=' . $this->session->data['user_token'], 'SSL'),
            'separator' => ' :: '
        );

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('heading_title'),
            'href' => $this->url->link('extension/payment/ckassa', 'user_token=' . $this->session->data['user_token'], 'SSL'),
            'separator' => ' :: '
        );

        $data['action'] = $this->url->link('extension/payment/ckassa', 'user_token=' . $this->session->data['user_token'], 'SSL');

        $data['cancel'] = $this->url->link('extension/payment', 'user_token=' . $this->session->data['user_token'], 'SSL');


        $data['user_token'] = $this->session->data['user_token'];

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('extension/payment/ckassa', $data));
    }

    /**
     * 
     * @return array
     */
    public function defaultConfiguration() {

        $this->load->model('setting/setting');

        $serverName = $this->serverName();
        
        return [
            'payment_ckassa_is_test' => $this->config->get('payment_ckassa_is_test') ? $this->config->get('payment_ckassa_is_test') : 0,
            'payment_ckassa_status' => $this->config->get('payment_ckassa_status') ? $this->config->get('payment_ckassa_status') : 0,
            'payment_ckassa_invunic' => $this->config->get('payment_ckassa_invunic') ? $this->config->get('payment_ckassa_invunic') : 'SIMPLE',
            'payment_ckassa_url' => $this->config->get('payment_ckassa_url') ? $this->config->get('payment_ckassa_url') : '',
            'payment_ckassa_cb_url' => $this->config->get('payment_ckassa_cb_url') ? $this->config->get('payment_ckassa_cb_url') : $serverName . '/index.php?route=extension/payment/ckassa/callback',
            'payment_ckassa_success_url' => $this->config->get('payment_ckassa_success_url') ? $this->config->get('payment_ckassa_success_url') : $serverName,
            'payment_ckassa_fail_url' => $this->config->get('payment_ckassa_fail_url') ? $this->config->get('payment_ckassa_fail_url') : $serverName,
            'payment_ckassa_secret' => $this->config->get('payment_ckassa_secret') ? $this->config->get('payment_ckassa_secret') : '',
            'payment_ckassa_shop_key' => $this->config->get('payment_ckassa_shop_key') ? $this->config->get('payment_ckassa_shop_key') : '',
            'payment_ckassa_currency' => 'RUB', //$this->config->get('ckassa_currency') ? $this->config->get('ckassa_currency') : 'RUB',
            'payment_ckassa_lang' => 'RU', //$this->config->get('ckassa_lang') ? $this->config->get('ckassa_lang') : 'RU',
            'payment_ckassa_country' => $this->config->get('payment_ckassa_country') ? $this->config->get('payment_ckassa_country') : 'RU',
            'payment_ckassa_taxation' => $this->config->get('payment_ckassa_taxation') ? $this->config->get('payment_ckassa_taxation') : 'osn',
            'payment_ckassa_tax' => $this->config->get('payment_ckassa_tax') ? $this->config->get('payment_ckassa_tax') : 'none',
            'payment_ckassa_tax_delivery' => $this->config->get('payment_ckassa_tax_delivery') ? $this->config->get('payment_ckassa_tax_delivery') : 'none',
            'payment_ckassa_payment_method' => $this->config->get('payment_ckassa_payment_method') ? $this->config->get('payment_ckassa_payment_method') : 'full_prepayment',
            'payment_ckassa_payment_object' => $this->config->get('payment_ckassa_payment_object') ? $this->config->get('payment_ckassa_payment_object') : 'commodity',
            'payment_ckassa_order_status_before_payment' => $this->config->get('payment_ckassa_order_status_before_payment') ? $this->config->get('payment_ckassa_order_status_before_payment') : '',
            'payment_ckassa_order_status_after_payment' => $this->config->get('payment_ckassa_order_status_after_payment') ? $this->config->get('payment_ckassa_order_status_after_payment') : '',
            'payment_ckassa_sort_order' => $this->config->get('payment_ckassa_sort_order') ? $this->config->get('payment_ckassa_sort_order') : '',
        ];
    }

    function serverName() {
        $protocol = "http";
        if ((isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on') || $_SERVER['SERVER_PORT'] == 443) {
            $protocol = "https";
        }

        return "{$protocol}://{$_SERVER['SERVER_NAME']}";
    }

    /**
     * 
     * @return array
     */
    public function prepareConfiguration() {

        $config = $this->defaultConfiguration();
//        if (isset($this->request->post['ckassa_url'])) {
//            $config['ckassa_url'] = $this->request->post['ckassa_url'];
//        }
        if (isset($this->request->post['payment_ckassa_cb_url'])) {
            $config['payment_ckassa_cb_url'] = $this->request->post['payment_ckassa_cb_url'];
        }
        if (isset($this->request->post['payment_ckassa_invunic'])) {
            $config['payment_ckassa_invunic'] = $this->request->post['payment_ckassa_invunic'];
        }
        if (isset($this->request->post['payment_ckassa_success_url'])) {
            $config['payment_ckassa_success_url'] = $this->request->post['payment_ckassa_success_url'];
        }
        if (isset($this->request->post['payment_ckassa_fail_url'])) {
            $config['payment_ckassa_fail_url'] = $this->request->post['payment_ckassa_fail_url'];
        }
        if (isset($this->request->post['payment_ckassa_secret'])) {
            $config['payment_ckassa_secret'] = $this->request->post['payment_ckassa_secret'];
        }
        if (isset($this->request->post['payment_ckassa_shop_key'])) {
            $config['payment_ckassa_shop_key'] = $this->request->post['payment_ckassa_shop_key'];
        }
        if (isset($this->request->post['payment_ckassa_currency'])) {
            $config['payment_ckassa_currency'] = $this->request->post['payment_ckassa_currency'];
        }
        if (isset($this->request->post['payment_ckassa_lang'])) {
            $config['payment_ckassa_lang'] = $this->request->post['payment_ckassa_lang'];
        }
        if (isset($this->request->post['payment_ckassa_country'])) {
            $config['payment_ckassa_country'] = $this->request->post['payment_ckassa_country'];
        }
        if (isset($this->request->post['payment_ckassa_taxation'])) {
            $config['payment_ckassa_taxation'] = $this->request->post['payment_ckassa_taxation'];
        }
        if (isset($this->request->post['payment_ckassa_tax'])) {
            $config['payment_ckassa_tax'] = $this->request->post['payment_ckassa_tax'];
        }
        if (isset($this->request->post['payment_ckassa_tax_delivery'])) {
            $config['payment_ckassa_tax_delivery'] = $this->request->post['payment_ckassa_tax_delivery'];
        }
        if (isset($this->request->post['payment_ckassa_payment_method'])) {
            $config['payment_ckassa_payment_method'] = $this->request->post['payment_ckassa_payment_method'];
        }
        if (isset($this->request->post['payment_ckassa_payment_object'])) {
            $config['payment_ckassa_payment_object'] = $this->request->post['payment_ckassa_payment_object'];
        }
        if (isset($this->request->post['payment_ckassa_status'])) {
            $config['payment_ckassa_status'] = $this->request->post['payment_ckassa_status'];
        }
        if (isset($this->request->post['payment_ckassa_order_status_before_payment'])) {
            $config['payment_ckassa_order_status_before_payment'] = $this->request->post['payment_ckassa_order_status_before_payment'];
        }
        if (isset($this->request->post['payment_ckassa_order_status_after_payment'])) {
            $config['payment_ckassa_order_status_after_payment'] = $this->request->post['payment_ckassa_order_status_after_payment'];
        }
        if (isset($this->request->post['payment_ckassa_sort_order'])) {
            $config['payment_ckassa_sort_order'] = $this->request->post['payment_ckassa_sort_order'];
        }

        return $config;
    }

    private function validate() {
        if (!$this->user->hasPermission('modify', 'extension/payment/ckassa')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }
        
        if ($this->request->post['payment_ckassa_is_test'] != 1) {
            if (!$this->request->post['payment_ckassa_secret']) {
                $this->error['ckassa_secret'] = $this->language->get('ckassa_secret_error');
            }

            // if (!$this->request->post['payment_ckassa_shop_key']) {
            //     $this->error['ckassa_shop_key'] = $this->language->get('ckassa_shop_key_error');
            // }
        }

        if (!$this->error) {
            return TRUE;
        } else {
            return FALSE;
        }
    }

}

?>
